<?php
/**
 * Broad functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @package Broad                   
 * @since Broad 1.0
 */

/**
 * Broad only works in WordPress 3.5 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '3.5-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

if ( ! function_exists( 'broad_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 * Create your own broad_setup() function to override in a child theme.
 *
 * @since Broad 1.0
 */
 
 
/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since Broad 1.0.1
 */
if ( ! isset( $content_width ) ) {
	$content_width = 660;
}
 
function broad_setup() {                                                  

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on broad, use a find and replace
	 * to change 'broad' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'broad', get_template_directory() . '/languages' );
	
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu().
	register_nav_menus( array( 'primary-nav' => __( 'Primary Navigation', 'broad' ), 'secondary-nav' => __( 'Secondary Navigation', 'broad' ) ) );
	                           
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );
	/*
	 * Enable support for Post Formats.
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat', ) );
	
		
	// Declare WooCommerce support
	add_theme_support( 'woocommerce' );
	
	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'broad_custom_background_args', array(
		'default-color' => '#f8f8f8',
		'default-image' => '',
	) ) );
	

}
endif; // broad_setup
add_action( 'after_setup_theme', 'broad_setup' );

function create_broad_db_table() {
	global $wpdb;
	$table = $wpdb->prefix . "broad_options";
	$query = "CREATE TABLE IF NOT EXISTS $table (
	  option_id int(255) NOT NULL auto_increment,
	  option_name varchar(200) NOT NULL,
	  option_value longtext NOT NULL,
	  option_activate varchar(200) NOT NULL default '1',
	  primary KEY (option_id)
	) ENGINE=InnoDB";
	$query = $wpdb->query($query);

	// Dumping data for table wp_broad_options
	if ($query) {
		$query = $wpdb->get_var("SELECT option_name FROM $table WHERE option_id = 1");
		if (! $query ) {
			$logo = get_template_directory_uri() . '/images/broad.png';
			$social_links = 'http://facebook.com, http://twitter.com, http://googleplus.com, http://linkedin.com';
			$adverts = get_template_directory_uri() . '/images/advert1.gif' . ', ' . get_template_directory_uri() . '/images/advert1.gif';
			$post_layout = maybe_serialize( array( "default" => "Default (List)", "masonry" => "Masonry" ) );
			$footer_background_image = get_template_directory_uri() . '/images/bg.png';
			
			$query = "INSERT INTO $table (option_id, option_name, option_value, option_activate) VALUES 
			(NULL, 'site_logo', '$logo', 1),
			(NULL, 'social_links', '$social_links', 1),
			(NULL, 'navigation_bar', '', 1),
			(NULL, 'featured_posts', '', 0),
			(NULL, 'adverts', '$adverts', 1),
			(NULL, 'post_layout', '$post_layout', 'default'),
			(NULL, 'sidebar', '', 1),
			(NULL, 'footer_background_image', '$footer_background_image', 0)";
			$query = $wpdb->query($query);
			
		}
	}
}                                                         
add_action('after_setup_theme', 'create_broad_db_table');

/**
 * Registers a widget area.
 * 
 * @since Broad 1.0
 */
function broad_widgets_init() {
	
	$before_title = '<div class="top-menu"><span class="col-lg-1" id="toggle"> + </span><h5 class="col-lg-10 pull-right"> - ';
	$after_title = ' - </h5></div>';
	
	register_sidebar( array(
		'name'          => __( 'Sidebar1', 'broad' ),
		'id'            => 'sidebar1',
		'description'   => __( 'Add widgets here to appear in your sidebar.', 'broad' ),
		'before_widget' => '<div id="%1$s" class="widget">',
		'after_widget'  => '</div>',
		'before_title'  => $before_title,
		'after_title'   => $after_title,
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Copyright Widget', 'broad' ),
		'id'            => 'copyright',
		'description'   => __( 'Add widgets here to appear in your footer.', 'broad' ),
		'before_widget' => '<div class="copyright">',
		'after_widget'  => '</div><div class="clear"></div>',
		'before_title'  => '',
		'after_title'   => '',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'broad' ),
		'id'            => 'footer1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'broad' ),
		'before_widget' => '<div class="footer1 %2$s">',
		'after_widget'  => '</div><div class="clear"></div><div class="clear"></div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'broad' ),
		'id'            => 'footer2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'broad' ),
		'before_widget' => '<div class="footer2 %2$s">',
		'after_widget'  => '</div><div class="clear"></div><div class="clear"></div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'broad' ),
		'id'            => 'footer3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'broad' ),
		'before_widget' => '<div class="footer3 %2$s">',
		'after_widget'  => '</div><div class="clear"></div><div class="clear"></div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'broad' ),
		'id'            => 'footer4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'broad' ),
		'before_widget' => '<div class="footer4 %2$s">',
		'after_widget'  => '</div><div class="clear"></div><div class="clear"></div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Widget 5', 'broad' ),
		'id'            => 'footer5',
		'description'   => __( 'Add widgets here to appear in your footer.', 'broad' ),
		'before_widget' => '<div class="footer5 %2$s">',
		'after_widget'  => '</div><div class="clear"></div><div class="clear"></div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );

}
add_action( 'widgets_init', 'broad_widgets_init' );

/**
* Create Broad options page
* 
* @since Broad 1.0 
* 
*/
function create_broad_option_page() {
    	
	/**
	 * Broad theme panel.
	 */
	require_once(get_template_directory() . '/inc/broad-option-page.php');                                                   
    add_theme_page('Broad Panel', 'Broad Panel', 'manage_options', 'broad-theme-panel', 'broad_theme_panel');
    add_theme_page("Overview", "Overview", 'manage_options', 'broad-overview' , 'broad_overview');
    add_theme_page("Contact", "Contact", 'manage_options', 'broad-contact' , 'broad_contact');
    
}
if (is_admin()) { add_action("admin_menu", "create_broad_option_page"); }

function broad_admin_tabs( $current = 'header' ) {
	$content = '';
    $tabs = array( 'header' => 'Header', 'body' => 'Body', 'footer' => 'Footer' );                   
    foreach( $tabs as $tab => $name ) {
        $class = ( $tab == $current ) ? 'class=active' : '';
        $content .= "<li><a $class href='?page=broad-theme-panel&tab=$tab'>$name</a></li>";   
    }
    return '<ul>' . $content . '</ul>';
	
}


function broad_get_option_data($for) {
	if ( empty($for) || ! isset($for) ) return;
	
	global $wpdb;
	$table = $wpdb->prefix . "broad_options";
	$query = "SELECT * FROM $table WHERE option_name = ";
	switch( $for ) {
		case 'theme_data': 
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'site_logo': 
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'social_links' :
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'navigation_bar':
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'featured_posts':
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'adverts':
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'post_layout':
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'sidebar':
			return $wpdb->get_row($query . "'$for'");
			break;
		case 'footer_background_image':
			return $wpdb->get_row($query . "'$for'");
			break;
		default :
			return false;
			break;
	}
	
}


function broad_update_option_data($for, $data = array()) {
	if ( empty($for) || ! isset($for) || !is_array($data) || empty($data) ) return;
	
	global $wpdb;
	$table = $wpdb->prefix . "broad_options";
	switch( $for ) {
		case 'site_logo': 
			return($wpdb->update($table, $data, array('option_name' => 'site_logo')));
			break;
		case 'social_links' :
			return $wpdb->update($table, $data, array('option_name' => 'social_links'));
			break;
		case 'navigation_bar':
			return $wpdb->update($table, $data, array('option_name' => 'navigation_bar'));
			break;
		case 'featured_posts':
			return $wpdb->update($table, $data, array('option_name' => 'featured_posts'));
			break;
		case 'adverts':
			return $wpdb->update($table, $data, array('option_name' => 'adverts'));
			break;
		case 'post_layout':
			return $wpdb->update($table, $data, array('option_name' => 'post_layout'));
			break;
		case 'sidebar':
			return $wpdb->update($table, $data, array('option_name' => 'sidebar'));
			break;
		case 'footer_background_image':
			return $wpdb->update($table, $data, array('option_name' => 'footer_background_image'));
			break;
		default :
			return false;
			break;
	}
	
}


/**
 * Check to see if a variable is set and not empty.
 * 
 * @param $data . The data to scan
 * 
 * @return mixed
 * 		if array, returns true if all is set & not empty otherwise return the keys(as array values) that are not set.
 * 		if (other data type) returns true if is set & not empty otherwise return false. 
 * 
 * @since Broad 1.0
 */
function broad_verify_data( $data ) {
	if ( is_array($data) ) {
        $return = '';
		while ( $value = current($data) ) {
			
			if ( $value !== '' ) { next($data); } elseif ( $value === '' || $value === ' ' ) { $return[] = key($data); }	
		}
		return $return;		
	} else { return (isset($data) && !empty($data)) ? true : false; }
}

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since Broad 1.0
 */
function broad_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'broad_javascript_detection', 0 );

/**
 * Enqueues General(backend & backend) scripts and styles.
 *
 * @since Broad 1.0
 */
function broad_scripts() {
	// Enqueue the styles.                                                                                 
	wp_enqueue_style( 'normalize', get_template_directory_uri() . '/css/normalize.css', array(), '3.0.2' );    
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), '3.3.4' );
	
	// Enqueue the scripts                                                                                
	wp_enqueue_script('jquery', get_template_directory_uri() . '/js/jquery.js', array(), '1.11.1', true);                
	wp_enqueue_script('bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'), '3.3.4', true);
}

/**
 * Enqueues frontend scripts and style.
 *
 * @since Broad 1.0
 */
function broad_frontend_scripts() {
	broad_scripts();
	
	// Enqueue the style.
	wp_enqueue_style( 'broad-custom-style', get_stylesheet_directory_uri() . '/style.css' );
	wp_enqueue_style( 'broad-frontend', get_template_directory_uri() . '/css/broad-frontend.css', array('normalize', 'bootstrap'), '1.0' );
	$post_layout = broad_get_option_data('post_layout');
	if ( $post_layout->option_activate == 'masonry' && !is_singular() ) {
		wp_enqueue_style( 'broad-frontend-masonry', get_template_directory_uri() . '/css/broad-frontend-masonry.css', array('normalize', 'bootstrap'), '1.0' );
	}
	
	// Enqueue the scripts
	wp_enqueue_script('html5', get_template_directory_uri() . '/js/html5.js', array(), '3.7.0'); wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );
	wp_enqueue_script('broad-frontend', get_template_directory_uri() . '/js/broad-frontend.js', array('jquery', 'bootstrap'), '1.0', true); 
	wp_enqueue_script('masonry', get_template_directory_uri() . '/js/masonry.js', array('jquery', 'bootstrap'), '3.3.2', true); 
}
add_action( 'wp_enqueue_scripts', 'broad_frontend_scripts' );



/**
 * Enqueues Backend script and style.
 *
 * @since Broad 1.0
 */
function broad_backend_scripts($hook) {
	
	if ($hook == 'appearance_page_broad-theme-panel') {
		
		broad_scripts();
		// Enqueue the style.
		wp_enqueue_style( 'broad-backend', get_template_directory_uri() . '/css/broad-backend.css', array('normalize', 'bootstrap'), '1.0' );
		
		// Enqueue the script                                                                                                                      
		wp_enqueue_script('broad-backend', get_template_directory_uri() . '/js/broad-backend.js', array('jquery', 'bootstrap'), '1.0');
	}
	
}
add_action( 'admin_enqueue_scripts', 'broad_backend_scripts' );                                                           


/**
 * Broad classes.
 */
require get_template_directory() . '/inc/broad-classes.php';

/**
 * Broad template tags.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
* WooCommerce support
*/                                                              
require get_template_directory() . '/inc/broad-woocommerce.php';



function broad_header() {                                              
	$site_logo = broad_get_option_data('site_logo');      
	$social_links = broad_get_option_data('social_links');                
	list($fb, $tw, $gp, $in) = explode(', ', $social_links->option_value);
	?>
	<div class="col-sm-3 pull-left">
	<?php if ( $site_logo->option_activate == 1 && !empty($site_logo->option_value) ) : ?>
	<img src="<?php echo $site_logo->option_value; ?>" class="logo">
	<?php
		else :
		printf( '<span class="col-lg-12 cartoon" style="font-size: 150%%;">%1$s</span> <span class="col-lg-12" style="font-size: 120%%;">%2$s</span>', get_bloginfo('name'), get_bloginfo('description') );
		endif;
	?>
	</div>
	<div class="col-sm-2 social pull-right">
	<?php if ($social_links->option_activate == 1) : ?>    
        <a href="<?php echo $fb; ?>" title="facebook"><img src="<?php echo get_template_directory_uri() . '/images/facebook.png'; ?>" alt="fb" id="social" /></a>
        <a href="<?php echo $tw; ?>" title="twitter"><img src="<?php echo get_template_directory_uri() . '/images/twitter.png'; ?>" alt="tw" id="social" /></a>
        <a href="<?php echo $gp; ?>" title="googleplus"><img src="<?php echo get_template_directory_uri() . '/images/googleplus.png'; ?>" alt="gp" id="social" /></a>
        <a href="<?php echo $in; ?>" title="linkedin"><img src="<?php echo get_template_directory_uri() . '/images/linkedin.png'; ?>" alt="in" id="social"  /></a>
    <?php endif; ?>
    </div> 
	<?php
	
}

function broad_primary_nav() {
	$navigaion_bar = broad_get_option_data('navigation_bar');
	if ($navigaion_bar->option_activate == 0) return;
	$args = array(
				'menu' => 'primary-nav',
				'container' => 'div',
				'container_class' => 'collapse navbar-collapse col-lg-12',
				'container_id' => 'broad-navbar-collapse1',
				'menu_class' => 'nav navbar-nav copperplateb',
				'echo' => true,
				'fallback_cb' => 'wp_bootstrap_navwalker::fallback',
				'depth' => 2,
				'walker' => new wp_bootstrap_navwalker(),
				'theme_location' => 'primary-nav'
				);
	?>                                           
    <nav class="navbar navbar-inverse" role="navigation" style="margin: 0 0 0.1% 0;">
        <div class="container full-complete">
	        <div class="row">                                                   
	            <div class="navbar-header">
	                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#broad-navbar-collapse1">
	                    <span class="sr-only">Toggle navigation</span> <span style="font-size: 200%; color: #ffffff;"> + </span>
	                </button>
	                <a class="navbar-brand <?php if (is_home()) : echo 'active-home'; endif;?>" href="<?php echo home_url(); ?>">
	                	<img src="<?php echo get_template_directory_uri() . '/images/home.jpg'; ?>" alt="home" />
	                </a>
	            </div>
	            <?php wp_nav_menu($args); ?>
	        </div>
	    </div>
    </nav>
	<?php
}

function broad_secondary_nav() {
	$navigaion_bar = broad_get_option_data('navigation_bar');
	if ($navigaion_bar->option_activate == 0) return;
	$args = array(
				'menu' => 'secondary-nav',
				'container' => 'div',
				'container_class' => 'collapse navbar-collapse col-lg-12',
				'container_id' => 'broad-navbar-collapse2',
				'menu_class' => 'nav navbar-nav copperplateb',
				'echo' => true,
				'fallback_cb' => 'wp_bootstrap_navwalker::fallback',
				'depth' => 2,
				'walker' => new wp_bootstrap_navwalker(),
				'theme_location' => 'secondary-nav'
				);
	?>
	<?php if ( has_nav_menu('secondary-nav') ) : ?>
    <nav class="navbar navbar-inverse" role="navigation" style="margin: 0.1% 0 0 0;">
        <div class="container full-complete">
	        <div class="row">                                                   
	            <div class="navbar-header">
	                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target="#broad-navbar-collapse2">
	                    <span class="sr-only">Toggle navigation</span>
	                    <i class="fa fa-th"></i>
	                </button>
	            </div>
	            <?php wp_nav_menu($args); ?>
	        </div>
	    </div>
    </nav>
    <?php endif; ?>
	
	<?php 
}

function broad_advert() {
	$adverts = broad_get_option_data('adverts');
	if ($adverts->option_activate == 0) return;
	list($advert1, $advert2) = explode(', ', $adverts->option_value);
	?>
    <div class="container">
    	<div class="row">
    		<figure class="col-sm-6"><img class="advert" src="<?php echo $advert1; ?>"></figure>
    		<figure class="col-sm-6"><img class="advert" src="<?php echo $advert2; ?>"></figure>
    	</div> 
    </div>
	<?php
}

function broad_paging_nav() {
	?>
	<nav class="navigation" role="navigation">
		<ul class="pager">
			<?php if (is_home() && !is_single()) : ?>
			<li class="previous"><?php previous_posts_link('← Newer'); ?></li> 
			<li class="next"><?php next_posts_link('Older →'); ?></li>
			<?php elseif(is_single()) : ?>
			<li class="previous"><?php echo get_previous_post_link('%link', ' ← %title'); ?></li> 
			<li class="next"><?php echo get_next_post_link('%link', '%title → '); ?></li>
		</ul>
	</nav>
	<?php endif;
}

function broad_breadcrumbs() {
	$cat = '';
	if ( get_the_category_list(', ') != null ) {
		$cat = sprintf( get_the_category_list(', ') . '%1$s', ' | ' );
	}
	printf(
		'<a href="%1$s">Home</a> %2$s %3$s %4$s',
		home_url(),
		' | ',
		$cat,
		the_title('', '', false)
	);
	echo '<br/>';
	printf( the_tags( null, ', ') );
	
}

function broad_comment_template() {
	// If comments are open or we have at least one comment, load up the comment template.
	if ( comments_open() || get_comments_number() ) :
		comments_template();
	endif;	
}

function broad_comment_form( $args = array() ) {
	
	$post_id = get_the_ID();
	$commenter = wp_get_current_commenter();
	$user = wp_get_current_user();
	$user_identity = $user->exists() ? $user->display_name : '';

	$args = wp_parse_args( $args );
	if ( ! isset( $args['format'] ) )
		$args['format'] = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';

	$req      = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$html_req = ( $req ? " required='required'" : '' );
	$html5    = 'html5' === $args['format'];
	$fields   =  array(
		'author' => '<div class="comment-form-author form-group col-md-6">' .
		            '<input class="form-control" placeholder="Author' . ( $req ? ' *' : '' ) . '" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '"' . $aria_req . $html_req . ' /></div>',
		'email'  => '<div class="comment-form-email form-group col-md-6">' .
		            '<input class="form-control" placeholder="Email ' . ( $req ? ' *' : '' ) . '" id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr(  $commenter['comment_author_email'] ) . '" aria-describedby="email-notes"' . $aria_req . $html_req  . ' /></div>',
		'url'    => '<div class="comment-form-url form-group col-md-12">' .
		            '<input class="form-control" placeholder="URL" id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" /></div>',
	);

	$required_text = sprintf( ' ' . __( 'Required fields are marked %s', 'broad' ), '<span class="required">*</span>' );

	$fields = apply_filters( 'comment_form_default_fields', $fields );
	$args = array(
		'fields'               => $fields,
		'comment_field'        => '<div class="comment-form-comment form-group col-md-12"><textarea id="comment" class="form-control" name="comment" rows="8" aria-describedby="form-allowed-tags" aria-required="true" required="required"></textarea></div>',
		'must_log_in'          => '<p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.', 'broad' ), wp_login_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
		'logged_in_as'         => '<p class="logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>', 'broad' ), get_edit_user_link(), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p>',
		'comment_notes_before' => '<p class="comment-notes"><span id="email-notes">' . __( 'Your email address will not be published.', 'broad' ) . '</span>'. ( $req ? $required_text : '' ) . '</p>',
		'comment_notes_after'  => '<div class="form-allowed-tags" id="form-allowed-tags form-group col-md-12"><small>' . sprintf( __( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s', 'broad' ), ' <code>' . allowed_tags() . '</code>' ) . '</small></div>',
		'id_form'              => 'commentform',
		'id_submit'            => 'submit',
		'class_submit'         => 'btn btn-primary pull-right',
		'name_submit'          => 'submit',
		'title_reply'          => __( 'Leave a Reply', 'broad' ),
		'title_reply_to'       => __( 'Leave a Reply to %s', 'broad' ),
		'cancel_reply_link'    => __( 'Cancel reply', 'broad' ),
		'label_submit'         => __( 'Post Comment', 'broad' ),
		'submit_button'        => '<input name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" />',
		'submit_field'         => '<div class="form-submit form-group col-md-12">%1$s %2$s</div>',
		'format'               => 'xhtml',
	);
	
	comment_form($args);
}


?>